# Expansehost

![expansehost banner](https://github.com/cyklon73/expansehost/blob/main/banner.png?raw=true)

[![PyPi version info](https://img.shields.io/pypi/v/expansehost.svg)](https://pypi.python.org/pypi/expansehost)
[![Total downloads for the project]( https://static.pepy.tech/personalized-badge/expansehost?period=total&units=international_system&left_color=grey&right_color=green&left_text=Downloads)](https://pepy.tech/project/expansehost)
[![PyPI supported Python versions](https://img.shields.io/pypi/pyversions/expansehost.svg)](https://pypi.python.org/pypi/expansehost)

## Installation

```bash
pip install expansehost
```

## Guide

- [Installation](#installation)
- [Description](#description)
- [Guide](#guide)
- [Documentation](#documentation)

## Description

This library is a Python API wrapper for the Expanse Host API, which you can use to read data from your server at Expansehost. This data includes: expiration date, RAM usage, network traffic and more


## Documentation

[![API Reference](https://img.shields.io/badge/API-Reference-blue.svg)](https://github.com/cyklon73/expansehost/wiki/API-Reference)
